AppNotificationMetadataModel class abstract

Implemented types

Properties

error AppNotificationErrorModel?
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AppNotificationMetadataModelBuilder)) AppNotificationMetadataModel
Rebuilds the instance.
inherited
toBuilder() AppNotificationMetadataModelBuilder
Converts the instance to a builder B.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppNotificationMetadataModel>
no setter

Static Methods

fromJson(String jsonString) AppNotificationMetadataModel
fromMap(Map<String, dynamic> map) AppNotificationMetadataModel