AppNotificationModel class abstract

Implemented types

Constructors

AppNotificationModel([void updates(AppNotificationModelBuilder)])
factory

Properties

content String?
no setterinherited
createdAt DateTime
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
rawMeta Map<String, dynamic>?
no setterinherited
readAt DateTime?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
no setterinherited
title String
no setterinherited
type String
no setterinherited
typedMeta AppNotificationMetadata?
no setterinherited
userId String
no setterinherited

Methods

copyWith({String? id, String? type, String? content, String? title, DateTime? readAt, DateTime? createdAt, Map<String, dynamic>? rawMeta, covariant AppNotificationMetadataModel? typedMeta, String? status, String? userId}) AppNotificationModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AppNotificationModelBuilder)) AppNotificationModel
Rebuilds the instance.
inherited
toBuilder() AppNotificationModelBuilder
Converts the instance to a builder B.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
withParsedMeta(NotificationMetadataMapper mapper, [Map<String, dynamic>? map]) AppNotificationModel
This method will return a new instance with correct decoded metadata of AppNotificationMetadata model If you are implementing a custom implementation of AppNotificationModel class you must make sure you are implementing this method and using to type your meta
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppNotificationModel>
no setter

Static Methods

fromJson(String jsonString) AppNotificationModel
fromMap(Map<String, dynamic> map) AppNotificationModel