getCountResponseParser property
Provides a way to transform unread notification response by providing a map body
Implementation
final int Function(Response response)? getCountResponseParser;
Provides a way to transform unread notification response by providing a map body
final int Function(Response response)? getCountResponseParser;