getListResponseParser property
Provides a way to transform Notification response by providing a map body
Implementation
final List<AppNotification> Function(Response response)? getListResponseParser;
Provides a way to transform Notification response by providing a map body
final List<AppNotification> Function(Response response)? getListResponseParser;