metadataMapper property
Provide a custom function to utilize in order to map your custom Metadata
Implementation
final NotificationMetadataMapper? metadataMapper;
Provide a custom function to utilize in order to map your custom Metadata
final NotificationMetadataMapper? metadataMapper;