AppNotification class abstract

Implementers

Constructors

AppNotification()

Properties

content String?
no setter
createdAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
rawMeta Map<String, dynamic>?
no setter
readAt DateTime?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
no setter
title String
no setter
type String
no setter
typedMeta AppNotificationMetadata?
no setter
userId String
no setter

Methods

copyWith({String? id, String? type, String? content, String? title, DateTime? readAt, DateTime? createdAt, Map<String, dynamic>? rawMeta, AppNotificationMetadata? typedMeta, String? status, String? userId}) AppNotification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withParsedMeta(NotificationMetadataMapper mapper, [Map<String, dynamic>? map]) AppNotification?
This method will return a new instance with correct decoded metadata of AppNotificationMetadata model If you are implementing a custom implementation of AppNotificationModel class you must make sure you are implementing this method and using to type your meta

Operators

operator ==(Object other) bool
The equality operator.
inherited