NotificationService class abstract

Implementers

Constructors

NotificationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

archive(AppNotification notification) Future<Either<Failure, Unit>>
archiveAll(Map<String, dynamic>? params) Future<Either<Failure, Unit>>
get({Map<String, dynamic>? params, required int skip}) Future<Either<Failure, List<AppNotification>>>
getNotificationCount(Map<String, dynamic>? params) Future<Either<Failure, int>>
getUnreadCount(Map<String, dynamic>? params) Future<Either<Failure, int>>
markAsRead(AppNotification notification) Future<Either<Failure, Unit>>
markAsReadAll(Map<String, dynamic>? params) Future<Either<Failure, Unit>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited