NotificationServiceImpl class

Inheritance
  • Object
  • RepoServiceBaseImpl
  • NotificationServiceImpl
Implemented types

Constructors

NotificationServiceImpl({required IHttpClient? httpClient, Logger? logger, required AppNotificationConfig notificationConfig})

Properties

client → IHttpClient?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
finalinherited
notificationConfig AppNotificationConfig
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

archive(AppNotification notification) Future<Either<Failure, Unit>>
override
archiveAll(Map<String, dynamic>? params) Future<Either<Failure, Unit>>
override
get({Map<String, dynamic>? params, required int skip}) Future<Either<Failure, List<AppNotification>>>
override
getNotificationCount(Map<String, dynamic>? params) Future<Either<Failure, int>>
override
getUnreadCount(Map<String, dynamic>? params) Future<Either<Failure, int>>
override
handleDefault<T>(Future<Either<Failure, T>> callback(Left<Failure, T> left(Failure failure), Right<Failure, T> right(T result)), {Either<Failure, T>? onError(Object error, Left<Failure, T> left(Failure failure), Right<Failure, T> right(T result), StackTrace stackTrace)?}) Future<Either<Failure, T>>
Provides you with an easy way to handle common service logic This helper will help you with some boilerplate needed when implementing handling of async service logic following our architecture
inherited
handleHttpBaseRequest<T>(BaseRequest request, {required DataOrFailureHandleResponse<T> onResponse, DataOrFailureHandleException<T>? onError, List<int> successStatuses = const [200, 201, 202, 203, 204], bool debugRequestBody = true, bool overrideTextContentTypeHeader = true}) Future<Either<Failure, T>>
Provides you with an easy way to handle a BaseRequest This helper provides you more control over the type of request being send it will help you with some boilerplate needed when implementing handling http request following our architecture It also provides early access to the request details before performing the request so it be better for logging request its commonly the return type of a HttpClient in most of its methods (get, post, patch, put, etc)
inherited
handleHttpRequestResponse<T>(Future<Response> futureResponse, {required DataOrFailureHandleResponse<T> onResponse, DataOrFailureHandleException<T>? onError, List<int> successStatuses = const [200, 201, 202, 203, 204], bool debugRequestBody = true}) Future<Either<Failure, T>>
Provides you with an easy way to handle common Http API request This helper will help you with some boilerplate needed when implementing handling http request following our architecture futureResponse its commonly the return type of a HttpClient in most of its methods (get, post, patch, put, etc)
inherited
markAsRead(AppNotification notification) Future<Either<Failure, Unit>>
override
markAsReadAll(Map<String, dynamic>? params) Future<Either<Failure, Unit>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrapAndHandleHttpBaseRequest<T>(FutureOr<BaseRequest> requestFn(), {required DataOrFailureHandleResponse<T> onResponse, DataOrFailureHandleException<T>? onError, List<int> successStatuses = const [200, 201, 202, 203, 204], bool debugRequestBody = true, bool overrideTextContentTypeHeader = true}) Future<Either<Failure, T>>
Provides you with an easy way to handle a BaseRequest This helper provides you more control over the type of request being send it will help you with some boilerplate needed when implementing handling http request following our architecture It also provides early access to the request details before performing the request so it be better for logging request its commonly the return type of a HttpClient in most of its methods (get, post, patch, put, etc)
inherited
wrapAndHandleHttpRequestResponse<T>(Future<Response> futureResponse(), {required DataOrFailureHandleResponse<T> onResponse, DataOrFailureHandleException<T>? onError, List<int> successStatuses = const [200, 201, 202, 203, 204], bool debugRequestBody = true}) Future<Either<Failure, T>>
Provides you with an easy way to handle common Http API request This helper will help you with some boilerplate needed when implementing handling http request following our architecture futureResponse its commonly the return type of a HttpClient in most of its methods (get, post, patch, put, etc)
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited