buildWhen property
Function to specify when to execute builder, this prevents uneccesary renderings
Implementation
final bool Function(AppNotificationState oldState, AppNotificationState state)? buildWhen;
Function to specify when to execute builder, this prevents uneccesary renderings
final bool Function(AppNotificationState oldState, AppNotificationState state)? buildWhen;