AppNotificationConfig class

Constructors

AppNotificationConfig({int? notificationLimit, Uri archiveApiEndpoint(AppNotification notification)?, BaseRequest markAsReadRequestMapper(Request request, AppNotification notification)?, BaseRequest archiveRequestMapper(Request request, AppNotification notification)?, BaseRequest archiveAllRequestMapper(Request request)?, Uri archiveAllApiEndpoint(Map<String, dynamic>? params)?, Uri markAllAsReadApiEndpoint(Map<String, dynamic>? params)?, BaseRequest markAllAsReadRequestMapper(Request request)?, int getCountResponseParser(Response response)?, List<AppNotification> getListResponseParser(Response response)?, required Uri getListApiEndpoint(Map<String, dynamic>? params), Uri markAsReadCompleteApiEndpoint(AppNotification notification)?, required Uri getCountApiEndpoint(Map<String, dynamic>? params), NotificationMetadataMapper? metadataMapper, String? archiveMethod})
const

Properties

archiveAllApiEndpoint Uri Function(Map<String, dynamic>? params)?
Provides an endpoint to be used when trying to archive
final
archiveAllRequestMapper → BaseRequest Function(Request request)?
Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request
final
archiveApiEndpoint Uri Function(AppNotification notification)?
Provides an endpoint to be used when trying to archive
final
archiveMethod String?
Provides a custom http method to archive a notification
final
archiveRequestMapper → BaseRequest Function(Request request, AppNotification notification)?
Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request Example function(notification) { return { 'notification': notification, }
final
getCountApiEndpoint Uri Function(Map<String, dynamic>? params)
Provides an endpoint to be used when trying to get Unread Notification Count
final
getCountResponseParser int Function(Response response)?
Provides a way to transform unread notification response by providing a map body
final
getListApiEndpoint Uri Function(Map<String, dynamic>? params)
Provides an endpoint to be used when trying to get Notifications
final
getListResponseParser List<AppNotification> Function(Response response)?
Provides a way to transform Notification response by providing a map body
final
hashCode int
The hash code for this object.
no setterinherited
markAllAsReadApiEndpoint Uri Function(Map<String, dynamic>? params)?
Provides an endpoint to be used when trying to mark all as read
final
markAllAsReadRequestMapper → BaseRequest Function(Request request)?
Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request
final
markAsReadCompleteApiEndpoint Uri Function(AppNotification notification)?
Provides an endpoint to be used when trying to mark as read the notifications
final
markAsReadRequestMapper → BaseRequest Function(Request request, AppNotification notification)?
Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request Example function(notification) { return { 'notification': notification, } }
final
metadataMapper NotificationMetadataMapper?
Provide a custom function to utilize in order to map your custom Metadata
final
notificationLimit int?
Provides a way to limit the number of notifications to be fetched
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationLimit, Uri archiveApiEndpoint(AppNotification notification)?, BaseRequest markAsReadRequestMapper(Request request, AppNotification notification)?, BaseRequest archiveRequestMapper(Request request, AppNotification notification)?, BaseRequest archiveAllRequestMapper(Request request)?, Uri archiveAllApiEndpoint()?, int getCountResponseParser(Response response)?, List<AppNotification> getListResponseParser(Response response)?, Uri getListApiEndpoint(Map<String, dynamic>? params)?, Uri markAsReadCompleteApiEndpoint(AppNotification notification)?, Uri getCountApiEndpoint(Map<String, dynamic>? params)?, Uri markAllAsReadApiEndpoint(Map<String, dynamic>? params)?, BaseRequest markAllAsReadRequestMapper(Request request)?, NotificationMetadataMapper? metadataMapper, String? archiveMethod}) AppNotificationConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited