archiveAllRequestMapper property
BaseRequest Function(Request request)?
archiveAllRequestMapper
final
Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request
Implementation
final BaseRequest Function(Request request)? archiveAllRequestMapper;