archiveRequestMapper property
Provides a custom function that allows you to customize the way your request's is sent to the API It gives you access to the current fabricated request so you just may change some headers You can provide a hole new request Example function(notification) { return { 'notification': notification, }
Implementation
final BaseRequest Function(
Request request,
AppNotification notification,
)? archiveRequestMapper;