This method will return a new instance with correct decoded metadata of AppNotificationMetadata model
If you are implementing a custom implementation of AppNotificationModel class you must make sure you
are implementing this method and using to type your meta